@@ -16,10 +16,10 @@
 
 
 import datetime
+import itertools
 from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import timeutils
-import six
 
 from watcher.common import context as watcher_context
 from watcher.common import scheduling
@@ -33,13 +33,14 @@ LOG = log.getLogger(__name__)
 
 class APISchedulingService(scheduling.BackgroundSchedulerService):
 
-    def __init__(self, gconfig=None, **options):
+    def __init__(self, gconfig={}, **options):
         self.services_status = {}
-        gconfig = None or {}
         super(APISchedulingService, self).__init__(gconfig, **options)
 
     def get_services_status(self, context):
         services = objects.service.Service.list(context)
+        active_s = objects.service.ServiceStatus.ACTIVE
+        failed_s = objects.service.ServiceStatus.FAILED
         for service in services:
             result = self.get_service_status(context, service.id)
             if service.id not in self.services_status:
@@ -49,12 +50,39 @@ class APISchedulingService(scheduling.BackgroundSchedulerService):
                 self.services_status[service.id] = result
                 notifications.service.send_service_update(context, service,
                                                           state=result)
+                if (result == failed_s) and (
+                        service.name == 'watcher-decision-engine'):
+                    audit_filters = {
+                        'audit_type': objects.audit.AuditType.CONTINUOUS.value,
+                        'state': objects.audit.State.ONGOING,
+                        'hostname': service.host
+                    }
+                    ongoing_audits = objects.Audit.list(
+                        context,
+                        filters=audit_filters,
+                        eager=True)
+                    alive_services = [
+                        s.host for s in services
+                        if (self.services_status[s.id] == active_s and
+                            s.name == 'watcher-decision-engine')]
+
+                    round_robin = itertools.cycle(alive_services)
+                    for audit in ongoing_audits:
+                        audit.hostname = round_robin.__next__()
+                        audit.save()
+                        LOG.info('Audit %(audit)s has been migrated to '
+                                 '%(host)s since %(failed_host)s is in'
+                                 ' %(state)s',
+                                 {'audit': audit.uuid,
+                                  'host': audit.hostname,
+                                  'failed_host': service.host,
+                                  'state': failed_s})
 
     def get_service_status(self, context, service_id):
         service = objects.Service.get(context, service_id)
-        last_heartbeat = (service.last_seen_up or service.updated_at
-                          or service.created_at)
-        if isinstance(last_heartbeat, six.string_types):
+        last_heartbeat = (service.last_seen_up or service.updated_at or
+                          service.created_at)
+        if isinstance(last_heartbeat, str):
             # NOTE(russellb) If this service came in over rpc via
             # conductor, then the timestamp will be a string and needs to be
             # converted back to a datetime.
@@ -80,7 +108,8 @@ class APISchedulingService(scheduling.BackgroundSchedulerService):
         context = watcher_context.make_context(is_admin=True)
         self.add_job(self.get_services_status, name='service_status',
                      trigger='interval', jobstore='default', args=[context],
-                     next_run_time=datetime.datetime.now(), seconds=60)
+                     next_run_time=datetime.datetime.now(),
+                     seconds=CONF.periodic_interval)
         super(APISchedulingService, self).start()
 
     def stop(self):
