@@ -18,6 +18,7 @@
 import sys
 
 from oslo_config import cfg
+from oslo_policy import opts
 from oslo_policy import policy
 
 from watcher.common import exception
@@ -26,6 +27,12 @@ from watcher.common import policies
 _ENFORCER = None
 CONF = cfg.CONF
 
+# TODO(gmann): Remove setting the default value of config policy_file
+# once oslo_policy change the default value to 'policy.yaml'.
+# https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
+DEFAULT_POLICY_FILE = 'policy.yaml'
+opts.set_defaults(CONF, DEFAULT_POLICY_FILE)
+
 
 # we can get a policy enforcer by this init.
 # oslo policy support change policy rule dynamically.
