@@ -25,16 +25,21 @@ from watcher.conf import ceilometer_client
 from watcher.conf import cinder_client
 from watcher.conf import clients_auth
 from watcher.conf import collector
+from watcher.conf import datasources
 from watcher.conf import db
 from watcher.conf import decision_engine
 from watcher.conf import exception
 from watcher.conf import glance_client
 from watcher.conf import gnocchi_client
+from watcher.conf import grafana_client
+from watcher.conf import grafana_translators
 from watcher.conf import ironic_client
+from watcher.conf import keystone_client
 from watcher.conf import monasca_client
 from watcher.conf import neutron_client
 from watcher.conf import nova_client
 from watcher.conf import paths
+from watcher.conf import placement_client
 from watcher.conf import planner
 from watcher.conf import service
 
@@ -44,6 +49,7 @@ service.register_opts(CONF)
 api.register_opts(CONF)
 paths.register_opts(CONF)
 exception.register_opts(CONF)
+datasources.register_opts(CONF)
 db.register_opts(CONF)
 planner.register_opts(CONF)
 applier.register_opts(CONF)
@@ -52,9 +58,13 @@ monasca_client.register_opts(CONF)
 nova_client.register_opts(CONF)
 glance_client.register_opts(CONF)
 gnocchi_client.register_opts(CONF)
+keystone_client.register_opts(CONF)
+grafana_client.register_opts(CONF)
+grafana_translators.register_opts(CONF)
 cinder_client.register_opts(CONF)
 ceilometer_client.register_opts(CONF)
 neutron_client.register_opts(CONF)
 clients_auth.register_opts(CONF)
 ironic_client.register_opts(CONF)
 collector.register_opts(CONF)
+placement_client.register_opts(CONF)
