@@ -18,7 +18,6 @@ SQLAlchemy models for watcher service
 
 from oslo_db.sqlalchemy import models
 from oslo_serialization import jsonutils
-import six.moves.urllib.parse as urlparse
 from sqlalchemy import Boolean
 from sqlalchemy import Column
 from sqlalchemy import DateTime
@@ -33,7 +32,7 @@ from sqlalchemy import String
 from sqlalchemy import Text
 from sqlalchemy.types import TypeDecorator, TEXT
 from sqlalchemy import UniqueConstraint
-
+import urllib.parse as urlparse
 from watcher import conf
 
 CONF = conf.CONF
