@@ -15,8 +15,9 @@
 # limitations under the License.
 
 import datetime
+from unittest import mock
 
-import mock
+from oslo_config import cfg
 from oslo_utils import uuidutils
 
 from apscheduler import job
@@ -28,6 +29,7 @@ from watcher.db.sqlalchemy import api as sq_api
 from watcher.decision_engine.audit import continuous
 from watcher.decision_engine.audit import oneshot
 from watcher.decision_engine.model.collector import manager
+from watcher.decision_engine.strategy.strategies import base as base_strategy
 from watcher.decision_engine.strategy.strategies import dummy_strategy
 from watcher import notifications
 from watcher import objects
@@ -61,6 +63,8 @@ class TestOneShotAuditHandler(base.DbTestCase):
             goal=self.goal)
 
     @mock.patch.object(manager.CollectorManager, "get_cluster_model_collector")
+    @mock.patch.object(base_strategy.BaseStrategy, "compute_model",
+                       mock.Mock(stale=False))
     def test_trigger_audit_without_errors(self, m_collector):
         m_collector.return_value = faker.FakerModelCollector()
         audit_handler = oneshot.OneShotAuditHandler()
@@ -84,7 +88,7 @@ class TestOneShotAuditHandler(base.DbTestCase):
             expected_calls,
             self.m_audit_notifications.send_action_notification.call_args_list)
 
-    @mock.patch.object(dummy_strategy.DummyStrategy, "do_execute")
+    @mock.patch.object(base_strategy.BaseStrategy, "do_execute")
     @mock.patch.object(manager.CollectorManager, "get_cluster_model_collector")
     def test_trigger_audit_with_error(self, m_collector, m_do_execute):
         m_collector.return_value = faker.FakerModelCollector()
@@ -106,6 +110,8 @@ class TestOneShotAuditHandler(base.DbTestCase):
             self.m_audit_notifications.send_action_notification.call_args_list)
 
     @mock.patch.object(manager.CollectorManager, "get_cluster_model_collector")
+    @mock.patch.object(base_strategy.BaseStrategy, "compute_model",
+                       mock.Mock(stale=False))
     def test_trigger_audit_state_succeeded(self, m_collector):
         m_collector.return_value = faker.FakerModelCollector()
         audit_handler = oneshot.OneShotAuditHandler()
@@ -132,6 +138,8 @@ class TestOneShotAuditHandler(base.DbTestCase):
             self.m_audit_notifications.send_action_notification.call_args_list)
 
     @mock.patch.object(manager.CollectorManager, "get_cluster_model_collector")
+    @mock.patch.object(base_strategy.BaseStrategy, "compute_model",
+                       mock.Mock(stale=False))
     def test_trigger_audit_send_notification(self, m_collector):
         m_collector.return_value = faker.FakerModelCollector()
         audit_handler = oneshot.OneShotAuditHandler()
@@ -219,11 +227,23 @@ class TestAutoTriggerActionPlan(base.DbTestCase):
         mock_applier.assert_called_once_with(self.context,
                                              self.recommended_action_plan.uuid)
 
+    @mock.patch.object(oneshot.OneShotAuditHandler, 'do_execute')
+    def test_trigger_audit_with_force(self, mock_do_execute):
+        audit_handler = oneshot.OneShotAuditHandler()
+        self.audit.force = True
+        audit_handler.execute(self.audit, self.context)
+        self.assertTrue(mock_do_execute.called)
+
 
 class TestContinuousAuditHandler(base.DbTestCase):
 
     def setUp(self):
         super(TestContinuousAuditHandler, self).setUp()
+        p_audit_notifications = mock.patch.object(
+            notifications, 'audit', autospec=True)
+        self.m_audit_notifications = p_audit_notifications.start()
+        self.addCleanup(p_audit_notifications.stop)
+
         self.goal = obj_utils.create_test_goal(
             self.context, id=1, name=dummy_strategy.DummyStrategy.get_name())
         audit_template = obj_utils.create_test_audit_template(
@@ -237,8 +257,10 @@ class TestContinuousAuditHandler(base.DbTestCase):
                 audit_template_id=audit_template.id,
                 goal_id=self.goal.id,
                 audit_type=objects.audit.AuditType.CONTINUOUS.value,
-                goal=self.goal)
+                goal=self.goal,
+                hostname='hostname1')
             for id_ in range(2, 4)]
+        cfg.CONF.set_override("host", "hostname1")
 
     @mock.patch.object(objects.service.Service, 'list')
     @mock.patch.object(sq_api, 'get_engine')
@@ -377,11 +399,10 @@ class TestContinuousAuditHandler(base.DbTestCase):
         audit_handler = continuous.ContinuousAuditHandler()
         self.audits[0].next_run_time = (datetime.datetime.now() -
                                         datetime.timedelta(seconds=1800))
-        m_is_inactive.return_value = False
-        m_get_jobs.return_value = None
+        m_is_inactive.return_value = True
+        m_get_jobs.return_value = []
 
         audit_handler.execute_audit(self.audits[0], self.context)
-        m_execute.assert_called_once_with(self.audits[0], self.context)
         self.assertIsNotNone(self.audits[0].next_run_time)
 
     @mock.patch.object(objects.service.Service, 'list')
@@ -417,3 +438,77 @@ class TestContinuousAuditHandler(base.DbTestCase):
 
         audit_handler.launch_audits_periodically()
         m_remove_job.assert_called()
+
+    @mock.patch.object(continuous.ContinuousAuditHandler, 'get_planner',
+                       mock.Mock())
+    @mock.patch.object(base_strategy.BaseStrategy, "compute_model",
+                       mock.Mock(stale=False))
+    def test_execute_audit(self):
+        audit_handler = continuous.ContinuousAuditHandler()
+        audit_handler.execute_audit(self.audits[0], self.context)
+
+        expected_calls = [
+            mock.call(self.context, self.audits[0],
+                      action=objects.fields.NotificationAction.STRATEGY,
+                      phase=objects.fields.NotificationPhase.START),
+            mock.call(self.context, self.audits[0],
+                      action=objects.fields.NotificationAction.STRATEGY,
+                      phase=objects.fields.NotificationPhase.END),
+            mock.call(self.context, self.audits[0],
+                      action=objects.fields.NotificationAction.PLANNER,
+                      phase=objects.fields.NotificationPhase.START),
+            mock.call(self.context, self.audits[0],
+                      action=objects.fields.NotificationAction.PLANNER,
+                      phase=objects.fields.NotificationPhase.END)]
+
+        self.assertEqual(
+            expected_calls,
+            self.m_audit_notifications.send_action_notification.call_args_list)
+
+    @mock.patch.object(scheduling.BackgroundSchedulerService, 'get_jobs')
+    def test_is_audit_inactive(self, mock_jobs):
+        audit_handler = continuous.ContinuousAuditHandler()
+        mock_jobs.return_value = mock.MagicMock()
+        audit_handler._audit_scheduler = mock.MagicMock()
+
+        ap_jobs = [job.Job(mock.MagicMock(), name='execute_audit',
+                           func=audit_handler.execute_audit,
+                           args=(self.audits[0], mock.MagicMock()),
+                           kwargs={}),
+                   ]
+
+        audit_handler.update_audit_state(self.audits[1],
+                                         objects.audit.State.CANCELLED)
+        mock_jobs.return_value = ap_jobs
+        is_inactive = audit_handler._is_audit_inactive(self.audits[1])
+        self.assertTrue(is_inactive)
+        is_inactive = audit_handler._is_audit_inactive(self.audits[0])
+        self.assertFalse(is_inactive)
+
+    def test_check_audit_expired(self):
+        current = datetime.datetime.utcnow()
+
+        # start_time and end_time are None
+        audit_handler = continuous.ContinuousAuditHandler()
+        result = audit_handler.check_audit_expired(self.audits[0])
+        self.assertFalse(result)
+        self.assertIsNone(self.audits[0].start_time)
+        self.assertIsNone(self.audits[0].end_time)
+
+        # current time < start_time and end_time is None
+        self.audits[0].start_time = current+datetime.timedelta(days=1)
+        result = audit_handler.check_audit_expired(self.audits[0])
+        self.assertTrue(result)
+        self.assertIsNone(self.audits[0].end_time)
+
+        # current time is between start_time and end_time
+        self.audits[0].start_time = current-datetime.timedelta(days=1)
+        self.audits[0].end_time = current+datetime.timedelta(days=1)
+        result = audit_handler.check_audit_expired(self.audits[0])
+        self.assertFalse(result)
+
+        # current time > end_time
+        self.audits[0].end_time = current-datetime.timedelta(days=1)
+        result = audit_handler.check_audit_expired(self.audits[0])
+        self.assertTrue(result)
+        self.assertEqual(objects.audit.State.SUCCEEDED, self.audits[0].state)
