@@ -14,9 +14,9 @@
 #    under the License.
 
 import datetime
+from unittest import mock
 
 import iso8601
-import mock
 
 from watcher.common import exception
 from watcher.common import utils as common_utils
@@ -139,10 +139,10 @@ class TestActionPlanObject(base.DbTestCase):
         expected_action_plan = fake_saved_action_plan.copy()
         expected_action_plan[
             'created_at'] = expected_action_plan['created_at'].replace(
-                tzinfo=iso8601.iso8601.Utc())
+                tzinfo=iso8601.UTC)
         expected_action_plan[
             'updated_at'] = expected_action_plan['updated_at'].replace(
-                tzinfo=iso8601.iso8601.Utc())
+                tzinfo=iso8601.UTC)
 
         uuid = self.fake_action_plan['uuid']
         action_plan = objects.ActionPlan.get_by_uuid(
@@ -207,7 +207,7 @@ class TestCreateDeleteActionPlanObject(base.DbTestCase):
         action_plan.create()
         expected_action_plan = self.fake_action_plan.copy()
         expected_action_plan['created_at'] = expected_action_plan[
-            'created_at'].replace(tzinfo=iso8601.iso8601.Utc())
+            'created_at'].replace(tzinfo=iso8601.UTC)
         mock_create_action_plan.assert_called_once_with(expected_action_plan)
         self.assertEqual(self.context, action_plan._context)
 
@@ -239,9 +239,9 @@ class TestCreateDeleteActionPlanObject(base.DbTestCase):
         m_soft_delete_action_plan.return_value = fake_deleted_action_plan
         expected_action_plan = fake_deleted_action_plan.copy()
         expected_action_plan['created_at'] = expected_action_plan[
-            'created_at'].replace(tzinfo=iso8601.iso8601.Utc())
+            'created_at'].replace(tzinfo=iso8601.UTC)
         expected_action_plan['deleted_at'] = expected_action_plan[
-            'deleted_at'].replace(tzinfo=iso8601.iso8601.Utc())
+            'deleted_at'].replace(tzinfo=iso8601.UTC)
         del expected_action_plan['audit']
         del expected_action_plan['strategy']
 
